// -----------------------------------------------------------------------------------------
// DRIVER compatible CIO pour la Gestion de la liaison RS232 via le priphrique SCI-A
// (voir doc TI : http://www.ti.com/lit/an/spra861/spra861.pdf)
// -----------------------------------------------------------------------------------------
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <file.h>
// -----------------------------------------------------------------------------------------
#include "derivative.h"
#include "defio.h"
#include "gestion_uart_a.h"

// -----------------------------------------------------------------------------------------
#define CPU_FREQ 	 150E6
#define LSPCLK_FREQ  (CPU_FREQ/4)
#define SCI_FREQ 	 38400
#define SCI_PRD 	 (LSPCLK_FREQ/(SCI_FREQ*8))-1

// -----------------------------------------------------------------------------------------
BOOL UART_A_OPENED=FALSE;

// -----------------------------------------------------------------------------------------
void Init_UART_A(void)
{
InitSciaGpio();				// configure les ports associs  l'uart n1
DINT;						// Disable interrupts

EALLOW;
SciaRegs.SCIFFTX.bit.SCIRST = 0;		// [15] 0 to reset SCI transmit and receive channels, 1 to resume
asm ("    NOP");
asm ("    NOP");
asm ("    NOP");

SciaRegs.SCICCR.all  = 0x0007;			// 1 stop bit,  No loopback, No parity, 8 char bits, async mode, idle-line protocol
SciaRegs.SCICTL1.all = 0x0003;			// enable TX, RX, internal SCICLK, Disable RX ERR, SLEEP, TXWAKE
SciaRegs.SCICTL2.bit.TXINTENA   = 1;	// Test pour stopper les INT TX en trop - DISABLE that way.
SciaRegs.SCICTL2.bit.RXBKINTENA = 1;

//Uint16 u16SciBaud = SCI_PRD;
SciaRegs.SCIHBAUD = (((Uint16)SCI_PRD) & 0xFF00)>>8;
SciaRegs.SCILBAUD = (((Uint16)SCI_PRD) & 0x00FF);

SciaRegs.SCIFFTX.all = 0xC001;				// 1100 0000 0000 0001
//ScicRegs.SCIFFTX.bit.SCIRST       = 1;		// [15] 0 to reset SCI transmit and receive channels, 1 to resume
//ScicRegs.SCIFFTX.bit.SCIFFENA     = 1;		// [14] 1 = FIFO enhancements enabled
//ScicRegs.SCIFFTX.bit.TXFIFOXRESET = 0;		// [13] 0 = Reset Tx FIFO pointer and hold reset
//ScicRegs.SCIFFTX.bit.TXFFST       = 0;		// [12,8] 5 bits (read only !?)
//	ScicRegs.SCIFFTX.bit.TXFFINT				// [7] = - READ ONLY - Flag "interrupt has not occurred"
//ScicRegs.SCIFFTX.bit.TXFFINTCLR   = 0;		// [6] Write 1 to clear TXFFINT (0 has no effect)
//ScicRegs.SCIFFTX.bit.TXFFIENA     = 0;		// [5] 1 to enable interrupt Tx according to [0,4] functionality
//ScicRegs.SCIFFTX.bit.TXFFIL       = 0x01;	// [0,4] interrupt level (nbr of WORD in FIFO => interrupt)

SciaRegs.SCIFFRX.all = 0x002C;			// Interrupt when 0x0C bytes in Rcv FIFO + Rcv FIFO interrupt enabled
//	ScicRegs.SCIFFRX.bit.RXFFOVF;			// [15] READ ONLY - Overflow if 1
//ScicRegs.SCIFFRX.bit.RXFFOVRCLR  = 0;	// [14] CLR [15]
//ScicRegs.SCIFFRX.bit.RXFIFORESET = 0;	// [13] RXFIFO reset on 0
//ScicRegs.SCIFFRX.bit.RXFFST      = 0;	// [8,12] (Read only ?)
//	ScicRegs.SCIFFRX.bit.RXFFINT			// [7] READ_ONLY
//ScicRegs.SCIFFRX.bit.RXFFINTCLR  = 0;	// [6] Reset [7]
//ScicRegs.SCIFFRX.bit.RXFFIENA    = 1;	// [5] Enable interrupt on [0,4] match
//ScicRegs.SCIFFRX.bit.RXFFIL      = 8;	// [0,4] interrupt level
//	ScicRegs.SCIFFRX.bit.RXFFIL = 0x000C;	// Interrupt when 0x0C bytes in Rcv FIFO
//	ScicRegs.SCIFFRX.bit.RXFFIENA = 1;		// Rcv FIFO interrupt enabled
//	ScicRegs.SCIFFRX.all = 0x0000;			// Rcv FIFO interrupt disabled

SciaRegs.SCIFFCT.all = 0x00;

SciaRegs.SCICTL1.all = 0x0023;			// Relinquish SCI from Reset 0000 0000 0010 0011
//	ScicRegs.SCICTL1.bit.RXENA = 1;			// [0] Enable
//	ScicRegs.SCICTL1.bit.TXENA = 1;			// [1] Enable
//	ScicRegs.SCICTL1.bit.SWRESET = 1;		// [5] SW RESET

SciaRegs.SCIFFTX.bit.TXFIFOXRESET = 1;	// FIFO Tx reset
SciaRegs.SCIFFRX.bit.RXFIFORESET  = 1;	// FIFO Rx reset

EDIS;

EINT; // Enable Global interrupt INTM
}

// -----------------------------------------------------------------------------------------
int UART_A_open(const char *path, unsigned flags, int llv_fd)
{
UART_A_OPENED=TRUE;
return(1);	// OK
}

// -----------------------------------------------------------------------------------------
int UART_A_close(int dev_fd)
{
UART_A_OPENED=FALSE;
return(0);	// OK
}

// -----------------------------------------------------------------------------------------
int UART_A_read(int dev_fd, char *buf, unsigned count)
{
Uint16 RxData;
unsigned n=count;
while(n)
	{
	// Wait for inc character
	while(SciaRegs.SCIFFRX.bit.RXFFST ==0) { } // attend au moins 1 caractere dans la fifo
	// Get character
	RxData= SciaRegs.SCIRXBUF.all;
	*buf++=(char)RxData;
	n--;
	}
return(count);	// OK
}

// -----------------------------------------------------------------------------------------
int UART_A_write(int dev_fd, const char *buf, unsigned count)
{
unsigned n=count;
while(n)
	{
    while (SciaRegs.SCIFFTX.bit.TXFFST != 0) {}
    SciaRegs.SCITXBUF=*buf++;
    n--;
	}
return(count);	// OK
}

// -----------------------------------------------------------------------------------------
off_t UART_A_lseek(int dev_fd, off_t offset, int origin)
{
return(UART_A_ERR_FCN_NOT_DEFINED);	// cette fonction n'a pas de sens pour une UART
}

// -----------------------------------------------------------------------------------------
int UART_A_unlink(const char *path)
{
return(UART_A_ERR_FCN_NOT_DEFINED);	// cette fonction n'a pas de sens pour une UART
}

// -----------------------------------------------------------------------------------------
int UART_A_rename(const char *old_name, const char *new_name)
{
return(UART_A_ERR_FCN_NOT_DEFINED);	// cette fonction n'a pas de sens pour une UART
}

// -----------------------------------------------------------------------------------------
BOOL UART_A_is_char_ready(void)
{
return((BOOL)SciaRegs.SCIFFRX.bit.RXFFST);
}
