// -----------------------------------------------------------------------------------------
// Module de gestion de l'initialisation des priphriques du DSP
// -----------------------------------------------------------------------------------------
#include "derivative.h"
#include "init.h"
#include "defio.h"
#include "gestion_timer.h"


// -----------------------------------------------------------------------------------------
void InitHW(void)
{
    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	// Step 1 : Initialisation PLL, WatchDog, enable Peripheral Clocks
    // (voir DSP2833x_SysCtrl.c dans COMMON_LIB)
    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    InitSysCtrl();

    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    // Step 2 : initialisation des GPIO
    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

    // Initialisation de toutes les I/O en entre avec pull-up pour commencer
    InitGPIO();

    // Initialisation spcifique des I/O en fonction de l'application
    // TODO [ initialisation spcifique  placer ici ]

    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    // Step 3 : Initialisation du contrleur d'interruption et des vecteurs d'interruption
    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    DINT;			// Dsactive les interruptions
    InitPieCtrl();	// Initialisation du contrleur d'interruption (voir DSP2833x_PieCtrl.c)
    IER = 0x0000;	// Aucune interruption configure pour l'instant
    IFR = 0x0000;	// Efface les drapeaux d'interruption (ne laisse aucune interruption en attente)

    // Initialise la table des vecteurs d'interruption (PIE Vector) avec des pointeurs sur
    // les fonctions 'bouchons' dfinies par dfaut (voir DSP2833x_DefaultIsr.c)
    // (note : la table des vecteurs d'interruption est loge en RAM)
    InitPieVectTable();

    // Interrupts that are used in this example are re-mapped to
    EALLOW;  // autorise l'accs aux registres protgs (cas du registre PieVectTable)
    PieVectTable.TINT0 = &GESTION_INT_TIMER0;
    EDIS;    // dsactive l'accs aux registres protgs

    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    // Step 4. Initialisations des priphriques utiliss dans cette application
    // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   InitCpuTimers();   // Initialisation des timers (voir DSP2833x_CpuTimers.c)
   ConfigCpuTimer(&CpuTimer0, 150, 1000);	// Timer 0 -> interruption priodique = 1 ms @ 150MHz

   // To ensure precise timing, use write-only instructions to write to the entire register. Therefore, if any
   // of the configuration bits are changed in ConfigCpuTimer and InitCpuTimers (in DSP2833x_CpuTimers.h), the
   // below settings must also be updated.
   CpuTimer0Regs.TCR.all = 0x4001; // Use write-only instruction to set TSS bit = 0

   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // Step 5. Configure les interruptions qui doivent tre actives pour cette application
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   IER |= M_INT1;	//
   PieCtrlRegs.PIEIER1.bit.INTx7 = 1; // Enable TINT0 in the PIE: Group 1 interrupt 7

   // Enable global Interrupts and higher priority real-time debug events:
   EINT;   // Enable Global interrupt INTM
   ERTM;   // Enable Global realtime interrupt DBGM

   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // Step 6 : recopie en ram le code critique
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // This includes the following ISR functions: epwm1_timer_isr(), epwm2_timer_isr()
   // epwm3_timer_isr and and InitFlash();
   // The  RamfuncsLoadStart, RamfuncsLoadEnd, and RamfuncsRunStart
   // symbols are created by the linker. Refer to the 28335_FLASH_lnk.cmd file.
	#ifdef FLASH_CODE
   	MemCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);
	#endif

   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // Step 7 : Initialise les paramtres de la mmoire flash pour amliorer
   // les performances du code excut en RAM (car les paramtres en sortie
   // de RESET du DSP sont conservatifs, cette fonction doit avoir t
   // reloge en RAM au pralable car la modification dynamique des paramtres
   // de la FLASH risque de provoquer un dysfonctionnement)
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	#ifdef FLASH_CODE
    InitFlash();
	#endif

   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // Enable global Interrupts and higher priority real-time debug events:
   EINT; // Enable Global interrupt INTM
}


// -----------------------------------------------------------------------------------------
// Initialisation des I/O (configuration par dfaut pour un kit TMS320F28335)
// -----------------------------------------------------------------------------------------
void InitGPIO(void)
{
    EALLOW;

    // GPIO 0 (peut devenir EPWM1A)
    GpioCtrlRegs.GPAPUD.bit.GPIO0 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO0 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO0 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 1 (peut devenir EPWM1B)
    GpioCtrlRegs.GPAPUD.bit.GPIO1 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO1 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO1 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 2 (peut devenir EPWM2A)
    GpioCtrlRegs.GPAPUD.bit.GPIO2 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO2 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO2 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 3 (peut devenir EPWM2B)
    GpioCtrlRegs.GPAPUD.bit.GPIO3 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO3 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO3 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 4 (peut devenir EPWM3A)
    GpioCtrlRegs.GPAPUD.bit.GPIO4 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO4 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO4 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 5 (peut devenir EPWM3B)
    GpioCtrlRegs.GPAPUD.bit.GPIO5 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO5 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO5 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 6 (peut devenir EPWM4A)
    GpioCtrlRegs.GPAPUD.bit.GPIO6 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO6 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO6 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 7 (peut devenir EPWM4B)
    GpioCtrlRegs.GPAPUD.bit.GPIO7 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO7 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO7 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 8 (peut devenir EPWM5A)
    GpioCtrlRegs.GPAPUD.bit.GPIO8 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO8 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO8 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 9 (peut devenir EPWM5B)
    GpioCtrlRegs.GPAPUD.bit.GPIO9 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO9 = FCT_GPIO; 					// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO9 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 10 (peut devenir EPWM6A)
    GpioCtrlRegs.GPAPUD.bit.GPIO10 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO10 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO10 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 11 (peut devenir EPWM6B)
    GpioCtrlRegs.GPAPUD.bit.GPIO11 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO11 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO11 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 12
    GpioCtrlRegs.GPAPUD.bit.GPIO12 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO12 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO12 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 13
    GpioCtrlRegs.GPAPUD.bit.GPIO13 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO13 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO13 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 14
    GpioCtrlRegs.GPAPUD.bit.GPIO14 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO14 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO14 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 15
    GpioCtrlRegs.GPAPUD.bit.GPIO15 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX1.bit.GPIO15 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO15 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 16
    GpioCtrlRegs.GPAPUD.bit.GPIO16 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO16 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO16 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 17
    GpioCtrlRegs.GPAPUD.bit.GPIO17 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO17 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO17 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 18
    GpioCtrlRegs.GPAPUD.bit.GPIO18 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO18 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO18 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 19
    GpioCtrlRegs.GPAPUD.bit.GPIO19 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO19 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO19 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 20
    GpioCtrlRegs.GPAPUD.bit.GPIO20 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO20 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO20 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 21
    GpioCtrlRegs.GPAPUD.bit.GPIO21 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO21 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO21 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 22
    GpioCtrlRegs.GPAPUD.bit.GPIO22 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO22 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO22 = GPIO_DIR_INPUT; 			// dir = Input

    // GPIO 23
    GpioCtrlRegs.GPAPUD.bit.GPIO23 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO23 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO23 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 24
    GpioCtrlRegs.GPAPUD.bit.GPIO24 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO24 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO24 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 25
    GpioCtrlRegs.GPAPUD.bit.GPIO25 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO25 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO25 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 26
    GpioCtrlRegs.GPAPUD.bit.GPIO26 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO26 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO26 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 27
    GpioCtrlRegs.GPAPUD.bit.GPIO27 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO27 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO27 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 28
    GpioCtrlRegs.GPAPUD.bit.GPIO28 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO28 = FCT_GPIO; 				// fonction GPIO (signal dispo sur J5 et RX_SLAVE si J9 est mont (TX de U1))
    GpioCtrlRegs.GPADIR.bit.GPIO28 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 29
    GpioCtrlRegs.GPAPUD.bit.GPIO29 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO29 = FCT_GPIO; 				// fonction GPIO (signal dispo sur J4 et TX_SLAVE (RX de U1))
    GpioCtrlRegs.GPADIR.bit.GPIO29 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 30
    GpioCtrlRegs.GPAPUD.bit.GPIO30 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO30 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPADIR.bit.GPIO30 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 31 (LED1 de la carte CPU)
    GpioCtrlRegs.GPAPUD.bit.GPIO31 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPAMUX2.bit.GPIO31 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPADIR.bit.GPIO31 = GPIO_DIR_OUTPUT; 			// dir = output
    GpioDataRegs.GPASET.bit.GPIO31 = 1; 						// Met la sortie  l'tat haut (led teinte)

    //GPIO 32
    GpioCtrlRegs.GPBPUD.bit.GPIO32 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO32 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO32 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 33
    GpioCtrlRegs.GPBPUD.bit.GPIO33 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO33 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPBDIR.bit.GPIO33 = GPIO_DIR_OUTPUT; 			// dir = Input

    //GPIO 34 (LED2 de la carte CPU)
    GpioCtrlRegs.GPBPUD.bit.GPIO34 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO34 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO34 = GPIO_DIR_OUTPUT; 			// dir = output
    GpioDataRegs.GPBSET.bit.GPIO34 = 1; 						// Met la sortie  l'tat haut (led teinte)

    //GPIO 35
    GpioCtrlRegs.GPBPUD.bit.GPIO35 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO35 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO35 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 36
    GpioCtrlRegs.GPBPUD.bit.GPIO36 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO36 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO36 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 37
    GpioCtrlRegs.GPBPUD.bit.GPIO37 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO37 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO37 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 38
    GpioCtrlRegs.GPBPUD.bit.GPIO38 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO38 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO38 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 39
    GpioCtrlRegs.GPBPUD.bit.GPIO39 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO39 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO39 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 40
    GpioCtrlRegs.GPBPUD.bit.GPIO40 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO40 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO40 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 41
    GpioCtrlRegs.GPBPUD.bit.GPIO41 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO41 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO41 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 42
    GpioCtrlRegs.GPBPUD.bit.GPIO42 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO42 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO42 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 43
    GpioCtrlRegs.GPBPUD.bit.GPIO43 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO43 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO43 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 44
    GpioCtrlRegs.GPBPUD.bit.GPIO44 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO44 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO44 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 45
    GpioCtrlRegs.GPBPUD.bit.GPIO45 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO45 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO45 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 46
    GpioCtrlRegs.GPBPUD.bit.GPIO46 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO46 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO46 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 47
    GpioCtrlRegs.GPBPUD.bit.GPIO47 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX1.bit.GPIO47 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU))
    GpioCtrlRegs.GPBDIR.bit.GPIO47 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 48
    GpioCtrlRegs.GPBPUD.bit.GPIO48 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO48 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO48 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 49
    GpioCtrlRegs.GPBPUD.bit.GPIO49 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO49 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPBDIR.bit.GPIO49 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 50
    GpioCtrlRegs.GPBPUD.bit.GPIO50 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO50 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO50 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 51
    GpioCtrlRegs.GPBPUD.bit.GPIO51 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO51 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO51 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 52
    GpioCtrlRegs.GPBPUD.bit.GPIO52 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO52 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO52 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 53
    GpioCtrlRegs.GPBPUD.bit.GPIO53 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO53 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO53 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 54
    GpioCtrlRegs.GPBPUD.bit.GPIO54 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO54 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU))
    GpioCtrlRegs.GPBDIR.bit.GPIO54 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 55
    GpioCtrlRegs.GPBPUD.bit.GPIO55 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO55 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO55 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 56
    GpioCtrlRegs.GPBPUD.bit.GPIO56 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO56 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO56 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 57
    GpioCtrlRegs.GPBPUD.bit.GPIO57 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO57 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPBDIR.bit.GPIO57 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 58
    GpioCtrlRegs.GPBPUD.bit.GPIO58 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO58 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO58 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 59
    GpioCtrlRegs.GPBPUD.bit.GPIO59 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO59 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPBDIR.bit.GPIO59 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 60
    GpioCtrlRegs.GPBPUD.bit.GPIO60 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO60 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO60 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 61
    GpioCtrlRegs.GPBPUD.bit.GPIO61 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO61 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPBDIR.bit.GPIO61 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 62
    GpioCtrlRegs.GPBPUD.bit.GPIO62 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO62 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J5)
    GpioCtrlRegs.GPBDIR.bit.GPIO62 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 63
    GpioCtrlRegs.GPBPUD.bit.GPIO63 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPBMUX2.bit.GPIO63 = FCT_GPIO; 				// fonction GPIO (NC sur le KIT mais signal dispo sur J4)
    GpioCtrlRegs.GPBDIR.bit.GPIO63 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 64
    GpioCtrlRegs.GPCPUD.bit.GPIO64 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO64 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO64 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 65
    GpioCtrlRegs.GPCPUD.bit.GPIO65 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO65 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO65 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 66
    GpioCtrlRegs.GPCPUD.bit.GPIO66 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO66 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO66 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 67
    GpioCtrlRegs.GPCPUD.bit.GPIO67 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO67 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO67 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 68
    GpioCtrlRegs.GPCPUD.bit.GPIO68 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO68 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO68 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 69
    GpioCtrlRegs.GPCPUD.bit.GPIO69 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO69 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU))
    GpioCtrlRegs.GPCDIR.bit.GPIO69 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 70
    GpioCtrlRegs.GPCPUD.bit.GPIO70 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO70 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO70 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 71
    GpioCtrlRegs.GPCPUD.bit.GPIO71 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO71 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO71 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 72
    GpioCtrlRegs.GPCPUD.bit.GPIO72 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO72 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO72 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 73
    GpioCtrlRegs.GPCPUD.bit.GPIO73 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO73 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO73 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 74
    GpioCtrlRegs.GPCPUD.bit.GPIO74 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO74 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO74 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 75
    GpioCtrlRegs.GPCPUD.bit.GPIO75 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO75 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO75 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 76
    GpioCtrlRegs.GPCPUD.bit.GPIO76 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO76 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO76 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 77
    GpioCtrlRegs.GPCPUD.bit.GPIO77 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO77 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO77 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 78
    GpioCtrlRegs.GPCPUD.bit.GPIO78 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO78 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO78 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 79
    GpioCtrlRegs.GPCPUD.bit.GPIO79 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX1.bit.GPIO79 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO79 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 80
    GpioCtrlRegs.GPCPUD.bit.GPIO80 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX2.bit.GPIO80 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO80 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 81
    GpioCtrlRegs.GPCPUD.bit.GPIO81 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX2.bit.GPIO81 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO81 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 82
    GpioCtrlRegs.GPCPUD.bit.GPIO82 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX2.bit.GPIO82 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO82 = GPIO_DIR_INPUT; 			// dir = Input

    //GPIO 83
    GpioCtrlRegs.GPCPUD.bit.GPIO83 = GPIO_PULL_UP_ACTIVE;		// pull up activ pour fixer le potentiel (NC)
    GpioCtrlRegs.GPCMUX2.bit.GPIO83 = FCT_GPIO; 				// fonction GPIO (NC la carte CPU)
    GpioCtrlRegs.GPCDIR.bit.GPIO83 = GPIO_DIR_INPUT; 			// dir = Input


    // GPIO 84
    GpioCtrlRegs.GPCPUD.bit.GPIO84 = 0;		// pull up dsactiv
    GpioCtrlRegs.GPCMUX2.bit.GPIO84 = 0; 	// fonction GPIO (SW2-1 sur la carte CPU du KIT)
    GpioCtrlRegs.GPCDIR.bit.GPIO84 = 0; 	// GPIO = Input

    // GPIO 85
    GpioCtrlRegs.GPCPUD.bit.GPIO85 = 0;		// pull up dsactiv
    GpioCtrlRegs.GPCMUX2.bit.GPIO85 = 0; 	// fonction GPIO (SW2-2 sur la carte CPU du KIT)
    GpioCtrlRegs.GPCDIR.bit.GPIO85 = 0; 	// GPIO = Input

    // GPIO 86
    GpioCtrlRegs.GPCPUD.bit.GPIO86 = 0;		// pull up dsactiv
    GpioCtrlRegs.GPCMUX2.bit.GPIO86 = 0; 	// fonction GPIO (SW2-3 sur la carte CPU du KIT)
    GpioCtrlRegs.GPCDIR.bit.GPIO86 = 0; 	// GPIO = Input

    // GPIO 87
    GpioCtrlRegs.GPCPUD.bit.GPIO87 = 0;		// pull up dsactiv
    GpioCtrlRegs.GPCMUX2.bit.GPIO87 = 0; 	// fonction GPIO (SW2-4 sur la carte CPU du KIT)
    GpioCtrlRegs.GPCDIR.bit.GPIO87 = 0; 	// GPIO = Input

    EDIS;
}

