// -----------------------------------------------------------------------------------------
// Template pour les applications excutes sur un kit TMS320F28335
// -----------------------------------------------------------------------------------------
#include <stdio.h>
#include <file.h>
// -----------------------------------------------------------------------------------------
#include "main.h"
#include "init.h"
#include "gestion_uart_a.h"
#include "gestion_timer.h"

// -----------------------------------------------------------------------------------------
void animate(FILE *h);		// fonction pour dmo

// -----------------------------------------------------------------------------------------
void main(void)
{
int x;
char buffer[8];
FILE * dest;
FILE * hconsole;

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// Initialisation du DSP et ses priphriques
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
InitHW();
Init_UART_A();
InitVariables();

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// Recense le driver 'custom' pour pouvoir utiliser la liaison SCI n1
// comme une console
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
add_device("UART_A",		// nom du nouveau priphrique
			_SSA,			// Single Stream Allowed (on ne peut pas l'ouvrir deux fois simultanment)
			UART_A_open, 	// recense les 7 fonctions de base du driver
			UART_A_close,
			UART_A_read,
			UART_A_write,
			UART_A_lseek,
			UART_A_unlink,
			UART_A_rename);


// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// Test des fonctions lies  la console (stdout)
// (Note : les fonctions sont ignores en cas d'execution sur la cible
// sans connexion avec le debugger)
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
puts("Test console, Entrez un caractre: ");
x=getchar();
puts("\n\rGetchar done ...\n\r");
printf("Code saisi :0x%x\r\n",x);
// Force le systme  vider le flux vers la console
// (ou bien ajouter "\n"  la dernire chane envoye vers la console)
//fflush(stdout);

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// test des fonctions fichiers (accs virtuel au disque du PC hte via la liaison JTAG)
// (Note : les fonctions sont ignores en cas d'execution sur la cible
// sans connexion avec le debugger)
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
dest=fopen("test.txt","wt");
if (dest != NULL)
	{
	fputs("test ok", dest);
	fclose(dest);
	}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// demande l'accs  la liaison RS232
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
hconsole=fopen("UART_A:ess1","r+");		// acces en lecture + criture
setvbuf(hconsole, NULL, _IONBF, 0);		// les flux associ  la liaison RS232 ne doit pas tre bufferis
if (hconsole != NULL)
	{
	fputs("\n\r>",hconsole);			// prompt d'accueil sur la console RS232
	}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// Boucle principale
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
while(1)
	{
	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	// Boucle principale de l'application
	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	// exemple d'application : demo de l'utilisation de la console RS232
	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	wait(10);					// test de la fonction wait
	if (hconsole != NULL)		// acces  la liaison RS232 est valide ?
		{
		// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
		// gestion des donnes saisies par l'utilisateur sur la console RS232
		// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
		if (UART_A_is_char_ready())		// vrifie si un caracter est en attente pour ne pas bloquer la boucle
			{
			fflush(hconsole);
			buffer[0]=fgetc(hconsole);	// recuperre la donne reue (appel bloquant sur cette version, voir "UART_A_read" )
			fflush(hconsole);
			switch(buffer[0])			// traite la donne
				{
				case '?':
							fputs("\rMenu:\n\r",hconsole);
							fputs("1-> action n:1\n\r",hconsole);
							fputs("2-> action n:2\n\r",hconsole);
							fputs("3-> action n:3\n\r",hconsole);
							fputs("\n\r>",hconsole);
							break;
				case '1':
							fputs("\rAction 1 done\n\r>",hconsole);
							break;

				case '2':
							fputs("\rAction 2 done\n\r>",hconsole);
							break;

				case '3':
							fputs("\rAction 3 done\n\r>",hconsole);
							break;

				default:
							fputs("\r>?\n\r>",hconsole);
							break;
				}
			}

		// gere une petite animation simple sur la console RS232 pour cette demo
		animate(hconsole);
		}
	tmp1++;
	}
}

// -----------------------------------------------------------------------------------------
void animate(FILE *h)
{
static Uint16 anime_count=0;

// - - - - - - - - - - - - - - - - - - - - - -
// animation du curseur sur la console RS232
// - - - - - - - - - - - - - - - - - - - - - -
if (h)
	{
	switch(anime_count++)
	{
		case	10:  fputs("\r>|", h);
					break;

		case	20:  fputs("\r>/", h);
					break;

		case	30:  fputs("\r>-", h);
					break;

		default:	if (anime_count>=40)
						{
						anime_count=0;
						fputs("\r>\\", h);
						}
					break;
		}
	}
}

